===========
hornstone
===========


.. image:: https://travis-ci.org/umeboshi2/hornstone.svg?branch=master
    :target: https://travis-ci.org/umeboshi2/hornstone


.. image:: https://readthedocs.org/projects/hornstone/badge/?version=latest
        :target: https://hornstone.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/umeboshi2/hornstone/shield.svg
     :target: https://pyup.io/repos/github/umeboshi2/hornstone/
     :alt: Updates


.. image:: https://img.shields.io/pypi/v/hornstone.svg
        :target: https://pypi.python.org/pypi/hornstone


A bunch of rocks



Features
--------

* TODO

Credits
---------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage

